import requests
import xml.etree.ElementTree

__VERSION__ = '1.0'


class Meteobridge():
    def __init__(self):
        self._host = None
        self._user = None
        self._pass = None

    def __new__(self, Host, User, Pass):
        self._host = Host
        self._user = User
        self._pass = Pass
        self._winddir = 0
        self._windgust = 0
        self._wind = 0
        self._lowbat = False
        self._windchill = 0
        self._intemp = 0
        self._inhum = 0
        self._indew = 0
        self._press = 0
        self._seapress = 0
        self._fc = 0
        self._outtemp = 0
        self._outhum = 0
        self._outdew = 0
        self._rainrate = 0
        self._raintotal = 0
        self._raindelta = 0
        self._timestamp = None

        data = self._getData(self)

        retval = {
            'in': {
                'temperature': self._intemp,
                'humidity': self._inhum,
                'dewpoint': self._indew},
            'out': {
                'temperature': self._outtemp,
                'humidity': self._outhum,
                'dewpoint': self._outdew},
            'wind': {
                'direction': self._winddir,
                'speed': self._wind,
                'gust': self._windgust,
                'windchill': self._windchill},
            'pressure': {
                'current': self._press,
                'sealevel': self._seapress},
            'forecast': self._fc,
            'rain': {
                'rate': self._rainrate,
                'total': self._raintotal,
                'delta':self._raindelta},
            'lowbat': self._lowbat,
            'time': self._timestamp
            }
        
        return retval

    def _getData(self):
        reqUrl = 'http://' + self._user + ':' + self._pass + '@' + self._host + '/cgi-bin/livedataxml.cgi'
        response = requests.get(reqUrl)
        if response.status_code != 200:
            logger.warning("Invalid response from API")
        else:
            element = xml.etree.ElementTree.fromstring(response.content)
            for atype in element.findall('WIND'):
                self._winddir = atype.get('dir')
                self._wind = atype.get('wind')
                self._windgust = atype.get('gust')
                self._windchill = atype.get('chill')
            for atype in element.findall('TH'):
                self._outtemp = atype.get('temp')
                self._outhum = atype.get('hum')
                self._outdew = atype.get('dew')
                self._lowbat = atype.get('lowbat')
            for atype in element.findall('THB'):
                self._intemp = atype.get('temp')
                self._inhum = atype.get('hum')
                self._indew = atype.get('dew')
                self._press = atype.get('press')
                self._seapress = atype.get('seapress')
                self._fc = atype.get('fc')
            for atype in element.findall('RAIN'):
                self._raindelta = atype.get('delta')
                self._rainrate = atype.get('rate')
                self._raintotal = atype.get('total')
                self._timestamp = atype.get('date')
